@@ -1,5 +1,7 @@
 """
-Main interface for redshift service client waiters.
+Type annotations for redshift service client waiters.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift/waiters.html)
 
 Usage::
 
@@ -39,7 +41,7 @@ __all__ = (
 
 class ClusterAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.ClusterAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/redshift.html#Redshift.Waiter.ClusterAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/redshift.html#Redshift.Waiter.cluster_available)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift/waiters.html#clusteravailablewaiter)
     """
 
     def wait(
@@ -52,13 +54,14 @@ class ClusterAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [ClusterAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/redshift.html#Redshift.Waiter.ClusterAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/redshift.html#Redshift.Waiter.ClusterAvailableWaiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift/waiters.html#clusteravailable)
         """
 
 
 class ClusterDeletedWaiter(Boto3Waiter):
     """
-    [Waiter.ClusterDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/redshift.html#Redshift.Waiter.ClusterDeleted)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/redshift.html#Redshift.Waiter.cluster_deleted)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift/waiters.html#clusterdeletedwaiter)
     """
 
     def wait(
@@ -71,13 +74,14 @@ class ClusterDeletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [ClusterDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/redshift.html#Redshift.Waiter.ClusterDeleted.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/redshift.html#Redshift.Waiter.ClusterDeletedWaiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift/waiters.html#clusterdeleted)
         """
 
 
 class ClusterRestoredWaiter(Boto3Waiter):
     """
-    [Waiter.ClusterRestored documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/redshift.html#Redshift.Waiter.ClusterRestored)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/redshift.html#Redshift.Waiter.cluster_restored)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift/waiters.html#clusterrestoredwaiter)
     """
 
     def wait(
@@ -90,13 +94,14 @@ class ClusterRestoredWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [ClusterRestored.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/redshift.html#Redshift.Waiter.ClusterRestored.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/redshift.html#Redshift.Waiter.ClusterRestoredWaiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift/waiters.html#clusterrestored)
         """
 
 
 class SnapshotAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.SnapshotAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/redshift.html#Redshift.Waiter.SnapshotAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/redshift.html#Redshift.Waiter.snapshot_available)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift/waiters.html#snapshotavailablewaiter)
     """
 
     def wait(
@@ -116,5 +121,6 @@ class SnapshotAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [SnapshotAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/redshift.html#Redshift.Waiter.SnapshotAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/redshift.html#Redshift.Waiter.SnapshotAvailableWaiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift/waiters.html#snapshotavailable)
         """
